<?php

/**
 * dignify functions and definitions
  @package dignify
 *
*/

/* Set the content width in pixels, based on the theme's design and stylesheet.
*/
function dignify_content_width() {
	$GLOBALS['content_width'] = apply_filters( 'dignify_content_width', 980 );
}
add_action( 'after_setup_theme', 'dignify_content_width', 0 );


if( ! function_exists( 'dignify_theme_setup' ) ) {	
	
	function dignify_theme_setup() {
		load_theme_textdomain( 'dignify', get_template_directory() . '/languages' );
		
		// Add default posts and comments RSS feed links to head.
		add_theme_support( 'automatic-feed-links' );
		
		// Add title tag 
		add_theme_support( 'title-tag' );
		
		// Add default logo support		
        add_theme_support( 'custom-logo');

        add_theme_support('post-thumbnails');
         add_image_size('dignify-blog-front-thumbnail',370,225, true);
        

        
        
		
         // Add theme support for Semantic Markup
		add_theme_support( 'html5', array(
			'search-form',
			'comment-form',
			'comment-list',
			'gallery',
			'caption'
		) ); 

		$defaults = array(
			'default-image'          => get_template_directory_uri() .'/assets/img/bg9.jpg',
			'width'                  => 1920,
			'height'                 => 600,
			'uploads'                => true,
			'default-text-color'     => "fff",
			'wp-head-callback'       => 'dignify_header_style',
		);
		add_theme_support( 'custom-header', $defaults );

		// Menus
		register_nav_menus(array(
			'primary' => esc_html__('Primary Menu', 'dignify'),
		));
		// add excerpt support for pages
        add_post_type_support( 'page', 'excerpt' );
		
        if ( is_singular() && comments_open() ) {
			wp_enqueue_script( 'comment-reply' );
        }
		// Add theme support for selective refresh for widgets.
        add_theme_support( 'customize-selective-refresh-widgets' );
		
		 
    	// To use additional css
 	    add_editor_style( 'assets/css/editor-style.css' );
		
		//About Theme		
		if ( is_admin() ) {
			require( get_template_directory() . '/include/welcome-screen.php');
		}	
	}
	add_action( 'after_setup_theme', 'dignify_theme_setup' );
}

/**
 * Styles the header text color displayed on the page header title
 *
 */

function dignify_header_style()
{
	$header_text_color = get_header_textcolor();
	?>
		<style type="text/css">
			<?php
				//Check if user has defined any header image.
				if ( get_header_image() ) :
			?>
				.site-title, .site-description{
					color: #<?php echo esc_attr($header_text_color); ?>;
					
				}
			<?php endif; ?>	
		</style>
	<?php

}

/**
 * Load Upsell Button In Customizer
 * 2016 &copy; [Justin Tadlock](http://justintadlock.com).
 */

require_once( trailingslashit( get_template_directory() ) . '/include/upgrade/class-customize.php' );

add_action( 'admin_init', 'dignify_detect_button' );
	function dignify_detect_button() {
	wp_enqueue_style( 'dignify-info-button', get_template_directory_uri() . '/assets/css/import-button.css' );
}

/**
 * admin  JS scripts
 */
function dignify_admin_enqueue_scripts( $hook ) { 
	wp_enqueue_style( 
		'font-awesome', 
		get_template_directory_uri() . '/assets/css/font-awesome.css', 
		array(), 
		'4.7.0', 
		'all' 
	);
	wp_enqueue_style( 
		'erzen-admin', 
		get_template_directory_uri() . '/assets/admin/css/admin.css', 
		array(), 
		'1.0.0', 
		'all' 
	);
 
}
add_action( 'admin_enqueue_scripts', 'dignify_admin_enqueue_scripts' );

 
   // Register Nav Walker class_alias
    require get_template_directory(). '/class-wp-bootstrap-navwalker.php';
    require get_template_directory(). '/include/extras.php';

   /**

    * Enqueue CSS stylesheets
    */		
if( ! function_exists( 'dignify_enqueue_styles' ) ) {
	function dignify_enqueue_styles() {	
	
	    wp_enqueue_style('dignify-font', '//fonts.googleapis.com/css?family=Archivo+Black|Lato:300i,400,400i,700','');
		wp_enqueue_style('bootstrap', get_template_directory_uri() . '/assets/css/bootstrap.css','');
		wp_enqueue_style('animate-plug', get_template_directory_uri() .'/assets/css/animate.css','');
		wp_enqueue_style('font-awesome', get_template_directory_uri() .'/assets/css/font-awesome.css','');
		wp_enqueue_style('slicknav', get_template_directory_uri() .'/assets/css/slicknav.css','');
		wp_enqueue_style('owl-carousel', get_template_directory_uri() .'/assets/css/owl.carousel.css','');
		
		// main style
		wp_enqueue_style( 'dignify-style', get_stylesheet_uri() );
		
	}
	add_action( 'wp_enqueue_scripts', 'dignify_enqueue_styles' );
}

/**
 * Enqueue JS scripts
 */

if( ! function_exists( 'dignify_enqueue_scripts' ) ) {
	function dignify_enqueue_scripts() {   
		wp_enqueue_script('jquery');
		wp_enqueue_script('bootstrap', get_template_directory_uri() . '/assets/js/bootstrap.js',array(),'', true);
		wp_enqueue_script('dignify-main', get_template_directory_uri() . '/assets/js/plugins.js',array(),'', true);
		wp_enqueue_script('poptrox', get_template_directory_uri() . '/assets/js/poptrox.js',array(),'', true);	
        wp_enqueue_script('slicknav', get_template_directory_uri() . '/assets/js/jquery.slicknav.js',array(),'', true);
		wp_enqueue_script('dignify-scripts', get_template_directory_uri() . '/assets/js/scripts.js',array(),'', true);

	}
	add_action( 'wp_enqueue_scripts', 'dignify_enqueue_scripts' );
}


     /**
     * Register sidebars for dignify
     */

function dignify_sidebars() {

	// Blog Sidebar

	register_sidebar(array(
		'name' => esc_html__( 'Blog Sidebar', "dignify"),
		'id' => 'blog-sidebar',
		'description' => esc_html__( 'Sidebar on the blog layout.', "dignify"),
		'before_widget' => '<div id="%1$s" class="widget %2$s">',
		'after_widget' => '</div>',
		'before_title' => '<h4 class="sidebar-widget-title">',
		'after_title' => '</h4>',
	));
  	

	// Footer Sidebar

	register_sidebar(array(
		'name' => esc_html__( 'Footer Widget Area 1', "dignify"),
		'id' => 'dignify-footer-widget-area-1',
		'description' => esc_html__( 'The footer widget area 1', "dignify"),
		'before_widget' => ' <div class="footer-widgets %2$s">',
		'after_widget' => '</div> ',
		'before_title' => '<h4 class="widget-title">',
		'after_title' => '</h4>',
	));	
	

	register_sidebar(array(
		'name' => esc_html__( 'Footer Widget Area 2', "dignify"),
		'id' => 'dignify-footer-widget-area-2',
		'description' => esc_html__( 'The footer widget area 2', "dignify"),
		'before_widget' => '<div class="footer-widgets %2$s"> ',
		'after_widget' => ' </div>',
		'before_title' => '<h4>',
		'after_title' => '</h4>',
	));	
	
	register_sidebar(array(
		'name' => esc_html__( 'Footer Widget Area 3', "dignify"),
		'id' => 'dignify-footer-widget-area-3',
		'description' => esc_html__( 'The footer widget area 3', "dignify"),
		'before_widget' => '<div class="footer-widgets %2$s">',
		'after_widget' => '</div>',
		'before_title' => '<h4>',
		'after_title' => '</h4>',
	));	
	
	register_sidebar(array(
		'name' => esc_html__( 'Footer Widget Area 4', "dignify"),
		'id' => 'dignify-footer-widget-area-4',
		'description' => esc_html__( 'The footer widget area 4', "dignify"),
		'before_widget' => '<div class="footer-widgets m-unset gallery %2$s">',
		'after_widget' => '</div>',
		'before_title' => '<h4>',
		'after_title' => '</h4>',
	));		
}

add_action( 'widgets_init', 'dignify_sidebars' );
/**
 * Comment layout
 */
function dignify_comments( $comment, $args, $depth ) { ?>
	<div <?php comment_class('comments'); ?> id="<?php comment_ID() ?>">
		<?php if ($comment->comment_approved == '0') : ?>
			<div class="alert alert-info">
			  <p><?php esc_html_e( 'Your comment is awaiting moderation.', 'dignify' ) ?></p>
			</div>
		<?php endif; ?>
		
		<div class="single-comment comment-border">
			<div class="comment-img">
			    <?php echo get_avatar( $comment,'88', null,'User', array( 'class' => array( 'media-object','' ) )); ?>
		    </div>

			<div class="comment-text">
			    <h3>
				   <?php 
						/* translators: '%1$s %2$s: edit term */
				    printf(esc_html__( '%1$s %2$s', 'dignify' ), get_comment_author_link(), edit_comment_link(esc_html__( '(Edit)', 'dignify' ),'  ','') )
				    ?>
			     </h3>
			    <span><time datetime="<?php echo comment_time('c'); ?>">
				<?php printf(  /* translators: 1: date, 2: time */
					_x( '%1$s at %2$s', '1: date, 2: time', 'dignify' ),
						get_comment_date(),
						get_comment_time()
					); ?></time></span>
			    </span> 
			    <?php comment_text() ;?>
			    <?php comment_reply_link(array_merge( $args, array('depth' => $depth, 'max_depth' => $args['max_depth']))) ?>
		    </div>
		</div>
	</div>
<?php
} 

?>