<?php
/**
 * dignify Theme Customizer
 *
 * @package dignify
 */
/**
 * Add postMessage support for site title and description for the Theme Customizer.
 *
 * @param WP_Customize_Manager $wp_customize Theme Customizer object.
 */


function dignify_customize_register( $wp_customize ) {
	
	// dignify theme choice options
    if (!function_exists('dignify_section_choice_option')) :
        function dignify_section_choice_option()
        {
            $dignify_section_choice_option = array(
                'show' => esc_html__('Show', 'dignify'),
                'hide' => esc_html__('Hide', 'dignify')
            );
            return apply_filters('dignify_section_choice_option', $dignify_section_choice_option);
        }
    endif;


    if (!function_exists('dignify_column_layout_option')) :
        function dignify_column_layout_option()
        {
            $dignify_column_layout_option = array(
                '6' => esc_html__('2 Column Layout', 'dignify'),
                '4' => esc_html__('3 Column Layout', 'dignify'),
                '3' => esc_html__('4 Column Layout', 'dignify'),
            );
            return apply_filters('dignify_column_layout_option', $dignify_column_layout_option);
        }
    endif;



    /**
     * Sanitizing the select callback example
     *
    */
    if ( !function_exists('dignify_sanitize_select') ) :
        function dignify_sanitize_select( $input, $setting ) {

            // Ensure input is a slug.
            $input = sanitize_text_field( $input );

            // Get list of choices from the control associated with the setting.
            $choices = $setting->manager->get_control( $setting->id )->choices;

                // If the input is a valid key, return it; otherwise, return the default.
            return ( array_key_exists( $input, $choices ) ? $input : $setting->default );
        }
    endif;


    if ( !function_exists('dignify_column_layout_sanitize_select') ) :
        function dignify_column_layout_sanitize_select( $input, $setting ) {

            // Ensure input is a slug.
            $input = sanitize_text_field( $input );

            // Get list of choices from the control associated with the setting.
            $choices = $setting->manager->get_control( $setting->id )->choices;

            // If the input is a valid key, return it; otherwise, return the default.
            return ( array_key_exists( $input, $choices ) ? $input : $setting->default );
        }
    endif;
    
    /**
     * Drop-down Pages sanitization callback example.
     *
     * - Sanitization: dropdown-pages
     * - Control: dropdown-pages
     * 
     * Sanitization callback for 'dropdown-pages' type controls. This callback sanitizes `$page_id`
     * as an absolute integer, and then validates that $input is the ID of a published page.
     * 
     * @see absint() https://developer.wordpress.org/reference/functions/absint/
     * @see get_post_status() https://developer.wordpress.org/reference/functions/get_post_status/
     *
     * @param int                  $page    Page ID.
     * @param WP_Customize_Setting $setting Setting instance.
     * @return int|string Page ID if the page is published; otherwise, the setting default.
     */

    function dignify_sanitize_dropdown_pages( $page_id, $setting ) {
        // Ensure $input is an absolute integer.
        $page_id = absint( $page_id );
    
        // If $page_id is an ID of a published page, return it; otherwise, return the default.
        return ( 'publish' == get_post_status( $page_id ) ? $page_id : $setting->default );
    }


	
        /** Callout Section Settings Start **/

    $wp_customize->add_section(
        'dignify_footer_contact', 
        array(
            'title'   => esc_html__('Callout Section', 'dignify'),
            'description' => '',
            'priority'    => 4
        )
    );
    
    $wp_customize->add_setting(
        'dignify_contact_section_hideshow',
        array(
            'default' => 'hide',
            'sanitize_callback' => 'dignify_sanitize_select',
        )
    );

    $dignify_section_choice_option = dignify_section_choice_option();
    $wp_customize->add_control(
        'dignify_contact_section_hideshow',
        array(
            'type' => 'radio',
            'label' => esc_html__('Footer Callout', 'dignify'),
            'description' => esc_html__('Show/hide option for Footer Callout Section.', 'dignify'),
            'section' => 'dignify_footer_contact',
            'choices' => $dignify_section_choice_option,
            'priority' => 5
        )
    );

    $wp_customize->add_setting(
        'ctah_heading', 
        array(
            'default'   => '',
            'type'      => 'theme_mod',
            'sanitize_callback' => 'sanitize_text_field'
        )
    );

    $wp_customize->add_control(
        'ctah_heading', 
        array(
            'label'   => esc_html__('Callout Text', 'dignify'),
            'section' => 'dignify_footer_contact',
            'priority'  => 8
        )
    );

    $wp_customize->add_setting(
        'ctah_btn_url', 
        array(
            'default'   =>'',
            'type'      => 'theme_mod',
            'sanitize_callback' => 'esc_url_raw'
        )
    );

    $wp_customize->add_control(
        'ctah_btn_url', 
        array(
            'label'   => esc_html__('Button URL', 'dignify'),
            'section' => 'dignify_footer_contact',
            'priority'  => 10
        )
    );

    $wp_customize->add_setting(
        'ctah_btn_text', 
        array(
            'default'   => '',
            'type'      => 'theme_mod',
            'sanitize_callback' => 'sanitize_text_field'
        )
    );

    $wp_customize->add_control(
        'ctah_btn_text', 
        array(
            'label'   => esc_html__('Button Text', 'dignify'),
            'section' => 'dignify_footer_contact',
            'priority'  => 12
        )
    );
    
    /** Callout Section Settings End **/
	
	/** Footer Section Settings Start **/

	$wp_customize->add_section('dignify_footer_info',
        array(
            'title'       => __('Footer Section', 'dignify'),
            'description' => '',
            'priority'    => 5
        )
    );

    $wp_customize->add_setting('dignify_footer_section_hideshow',
        array(
            'default'           => 'show',
            'sanitize_callback' => 'dignify_sanitize_select',
        )
    );

    $dignify_footer_section_hide_show_option = dignify_section_choice_option();

    $wp_customize->add_control('dignify_footer_section_hideshow',
        array(
            'type'        => 'radio',
            'label'       => esc_html__('Footer Option', 'dignify'),
            'description' => esc_html__('Show/hide option for Footer Section.', 'dignify'),
            'section'     => 'dignify_footer_info',
            'choices'     => $dignify_footer_section_hide_show_option,
            'priority'    => 1
        ) 
    );


    $wp_customize->add_setting('dignify_footer_social_link_1', 
        array(
            'default'   =>  '',
            'type'      => 'theme_mod',
            'sanitize_callback' => 'esc_url_raw'
        )
    );

    $wp_customize->add_control('dignify_footer_social_link_1', 
        array(
            'label'   => esc_html__('Facebook URL', 'dignify'),
            'section' => 'dignify_footer_info',
            'priority'  => 7
        )
    );

    $wp_customize->add_setting('dignify_footer_social_link_2', 
        array(
            'default'   =>  '',
            'type'      => 'theme_mod',
            'sanitize_callback' => 'esc_url_raw'
        )
    );

    $wp_customize->add_control('dignify_footer_social_link_2', 
        array(
            'label'   => esc_html__('Twitter URL', 'dignify'),
            'section' => 'dignify_footer_info',
            'priority'  => 7
        )
    );

    $wp_customize->add_setting('dignify_footer_social_link_3', 
        array(
            'default'   =>  '',
            'type'      => 'theme_mod',
            'sanitize_callback' => 'esc_url_raw'
        )
    );

    $wp_customize->add_control('dignify_footer_social_link_3', 
        array(
            'label'   => esc_html__('Linkedin URL', 'dignify'),
            'section' => 'dignify_footer_info',
            'priority'  => 7
        )
    );

    $wp_customize->add_setting('dignify_footer_social_link_4', 
        array(
            'default'   =>  '',
            'type'      => 'theme_mod',
            'sanitize_callback' => 'esc_url_raw'
        )
    );

    $wp_customize->add_control('dignify_footer_social_link_4', 
        array(
            'label'   => esc_html__('Behance URL', 'dignify'),
            'section' => 'dignify_footer_info',
            'priority'  => 7
        )
    );


    $wp_customize->add_setting('dignify_footer_social_link_5', 
        array(
            'default'   =>  '',
            'type'      => 'theme_mod',
            'sanitize_callback' => 'esc_url_raw'
        )
    );

    $wp_customize->add_control('dignify_footer_social_link_5', 
        array(
            'label'   => esc_html__('Pinterest URL', 'dignify'),
            'section' => 'dignify_footer_info',
            'priority'  => 7
        )
    );
   

    $wp_customize->add_setting('dignify_footer_text',
         array(
            'default'             => '',
            'type'                => 'theme_mod',
            'sanitize_callback'   => 'wp_kses_post'
        )
    );

    $wp_customize->add_control('dignify_footer_text',
         array(
            'label'    => __('Copyright', 'dignify'),
            'section'  => 'dignify_footer_info',
            'type'     => 'textarea',
            'priority' => 2
    ));

    /** Footer Section Settings End **/

    $wp_customize->add_panel('frontpage', 
        array(
            'title'       => esc_html__('Front Page Options', 'dignify'),        
		    'description' => '',                                        
		     'priority'   => 3,
        )
    );
	

    /** Slider Section Settings Start **/

    // Panel - Slider Section 1
    $wp_customize->add_section('sliderinfo', 
        array(
            'title'       => esc_html__('Home Slider Section', 'dignify'),
            'description' => '',
            'panel'       => 'frontpage',
             'priority'   => 130
        )
    );

    // hide show
    
    $wp_customize->add_setting('dignify_slider_section_hideshow',
        array(
            'default'           => 'hide',
            'sanitize_callback' => 'dignify_sanitize_select',
        )
    );

    $dignify_slider_section_hide_show_option = dignify_section_choice_option();

    $wp_customize->add_control('dignify_slider_section_hideshow',
        array(
            'type'        => 'radio',
            'label'       => esc_html__('Slider Option', 'dignify'),
            'description' => esc_html__('Show/hide option for Slider Section.', 'dignify'),
            'section'     => 'sliderinfo',
            'choices'     => $dignify_slider_section_hide_show_option,
            'priority'    => 1
        )
    );
  
    $slider_no = 3;
        for( $i = 1; $i <= $slider_no; $i++ ) {
            $dignify_slider_page   = 'dignify_slider_page_'  .$i;
            $dignify_slider_btntxt = 'dignify_slider_btntxt_' . $i;
            $dignify_slider_btnurl = 'dignify_slider_btnurl_' .$i;
        

    $wp_customize->add_setting( $dignify_slider_page,
        array(
            'default'           => 1,
            'sanitize_callback' => 'dignify_sanitize_dropdown_pages',
        )
    );

    $wp_customize->add_control( $dignify_slider_page,
        array(
            'label'     => esc_html__( 'Slider Page ', 'dignify' ) .$i,
            'section'   => 'sliderinfo',
            'type'      => 'dropdown-pages',
            'priority'  => 100,
        )
    );


    $wp_customize->add_setting( $dignify_slider_btntxt,
        array(
            'default'           => '',
            'sanitize_callback' => 'sanitize_text_field',
        )
    );

    $wp_customize->add_control( $dignify_slider_btntxt,
        array(
            'label'        => esc_html__( 'Button Text','dignify' ),
            'section'      => 'sliderinfo',
            'type'         => 'text',
            'priority'     => 100,
        )
    );
        
    $wp_customize->add_setting( $dignify_slider_btnurl,
        array(
            'default'           => '',
            'sanitize_callback' => 'sanitize_text_field',
        )
    );

    $wp_customize->add_control( $dignify_slider_btnurl,
        array(
            'label'       => esc_html__( 'Button URL', 'dignify' ),
            'section'     => 'sliderinfo',
            'type'        => 'text',
            'priority'    => 100,
        )
    );

                
    }	
    /** Slider Section Settings End **/


    /** Aboutus Section Settings Start **/

    $wp_customize->add_section('aboutus',              
        array(
            'title'       => esc_html__('About Us Section', 'dignify'),          
            'description' => '',             
            'panel'       => 'frontpage',      
            'priority'    => 140,
        )
    );
    
    $wp_customize->add_setting('dignify_aboutus_section_hideshow',
        array(
            'default'           => 'hide',
            'sanitize_callback' => 'dignify_sanitize_select',
        )
    );

    $dignify_aboutus_section_hide_show_option = dignify_section_choice_option();

    $wp_customize->add_control('dignify_aboutus_section_hideshow',
        array(
            'type'        => 'radio',
            'label'       => esc_html__('About Us Option', 'dignify'),
            'description' => esc_html__('Show/hide option Section.', 'dignify'),
            'section'     => 'aboutus',
            'choices'     => $dignify_aboutus_section_hide_show_option,
            'priority'    => 1
        )
    );


    // About Us Title

    $wp_customize->add_setting('dignify_aboutus_title',
        array(
            'default'           => '',
            'type'              => 'theme_mod',
            'sanitize_callback' => 'sanitize_text_field'
        )
     );

    $wp_customize->add_control('dignify_aboutus_title', 
        array(
            'label'    => __('About Us Title', 'dignify'),
            'section'  => 'aboutus',
            'priority' => 1
        )
    );
  
    $wp_customize->add_setting('dignify_aboutus_subtitle', 
        array(
            'default'           => '',
            'type'              => 'theme_mod',
            'sanitize_callback' => 'sanitize_text_field'
        )
    );

    $wp_customize->add_control('dignify_aboutus_subtitle',
        array(
            'label'    => __('About Us Description', 'dignify'),
            'section'  => 'aboutus', 
            'priority' => 4
        )
     );


    // About Us
   
  
    $wp_customize->add_setting( 'dignify_aboutus_page',
        array(
            'default'           => 1,
            'sanitize_callback' => 'dignify_sanitize_dropdown_pages',
        )
    );

    $wp_customize->add_control( 'dignify_aboutus_page',
        array(
            'label'        => esc_html__( 'About Us Page ', 'dignify' ),
            'section'      => 'aboutus',
            'type'         => 'dropdown-pages',
            'priority'     => 100,
        )
    );

    $wp_customize->add_setting( 'dignify_aboutus_btntxt',
        array(
            'default'           => '',
            'sanitize_callback' => 'sanitize_text_field',
        )
    );

    $wp_customize->add_control( 'dignify_aboutus_btntxt',
        array(
            'label'        => esc_html__( 'Button-Text','dignify' ),
            'section'      => 'aboutus',
            'type'         => 'text',
            'priority'     => 100,
        )
    );
        
    $wp_customize->add_setting( 'dignify_aboutus_btnurl',
        array(
            'default'           => '',
            'sanitize_callback' => 'sanitize_text_field',
        )
    );

    $wp_customize->add_control( 'dignify_aboutus_btnurl',
        array(
            'label'       => esc_html__( 'Button-URL', 'dignify' ),
            'section'     => 'aboutus',
            'type'        => 'text',
            'priority'    => 100,
        )
    );

    
    /** About Us Section Settings End **/


    /** Service Section Settings Start **/

	$wp_customize->add_section('services',              
        array(
            'title'       => esc_html__('Home Service Section', 'dignify'),          
            'description' => '',             
            'panel'       => 'frontpage',      
            'priority'    => 140,
        )
    );
    
    $wp_customize->add_setting('dignify_services_section_hideshow',
        array(
            'default'           => 'hide',
            'sanitize_callback' => 'dignify_sanitize_select',
        )
    );

    $dignify_services_section_hide_show_option = dignify_section_choice_option();

    $wp_customize->add_control(
        'dignify_services_section_hideshow',
        array(
            'type'        => 'radio',
            'label'       => esc_html__('Services Option', 'dignify'),
            'description' => esc_html__('Show/hide option Section.', 'dignify'),
            'section'     => 'services',
            'choices'     => $dignify_services_section_hide_show_option,
            'priority'    => 1
        )
    );


    // Services title
    $wp_customize->add_setting('dignify_services_title', 
        array(
            'default'           => '',
            'type'              => 'theme_mod',
            'sanitize_callback' => 'sanitize_text_field'
        )
    );


    $wp_customize->add_control('dignify_services_title',
        array(
           'label'    => __('Service Title', 'dignify'),
           'section'  => 'services',
           'priority' => 1
        )
    );

  
    $wp_customize->add_setting('dignify_services_subtitle',
        array(
            'default'           => '',
            'type'              => 'theme_mod',
            'sanitize_callback' => 'sanitize_text_field'
        )
    );


    $wp_customize->add_control('dignify_services_subtitle', 
        array(
           'label'    => __('Service Description', 'dignify'),
           'section'  => 'services', 
           'priority' => 4
        )
    );

// column layout
    $wp_customize->add_setting('dignify_column_layout',
        array(
            'default'           => '4',
            'sanitize_callback' => 'dignify_column_layout_sanitize_select',
        )
    );

    $dignify_services_column_layout = dignify_column_layout_option();

    $wp_customize->add_control('dignify_column_layout',
        array(
            'type'        => 'radio',
            'label'       => esc_html__('Column Layout option ', 'dignify'),
            'description' => '',
            'section'     => 'services',
            'choices'     => $dignify_services_column_layout,
            'priority'    => 2
            )
    );


    // Services 
   
    $service_no = 6;
        for( $i = 1; $i <= $service_no; $i++ ) {
            $dignify_servicepage = 'dignify_service_page_' . $i;
            $dignify_serviceicon = 'dignify_page_service_icon_' . $i;
        
    // Setting - Feature Icon
    $wp_customize->add_setting( $dignify_serviceicon,
        array(
            'default'           => '',
            'sanitize_callback' => 'sanitize_text_field',
        )
    );

    $wp_customize->add_control( $dignify_serviceicon,
        array(
            'label'         => esc_html__( 'Service Icon ', 'dignify' ).$i,
            'description'   =>  __('Select a icon in this list <a target="_blank" href="https://fontawesome.com/v4.7.0/icons/">Font Awesome icons</a> and enter the class name','dignify'),
            'section'       => 'services',
            'type'          => 'text',
            'priority'      => 100,
        )
    );
        
    $wp_customize->add_setting( $dignify_servicepage,
        array(
            'default'           => 1,
            'sanitize_callback' => 'dignify_sanitize_dropdown_pages',
        )
    );

    $wp_customize->add_control( $dignify_servicepage,
        array(
            'label'        => esc_html__( 'Service Page ', 'dignify' ) .$i,
            'section'      => 'services',
            'type'         => 'dropdown-pages',
            'priority'     => 100,
        )
    );
    }
    /** Service Section Settings End **/

    /** Portfolio Section Settings Start **/

	$wp_customize->add_section('portfolio',              
        array(
            'title'       => esc_html__('Portfolio Section', 'dignify'),          
            'description' => '',             
            'panel'       => 'frontpage',      
            'priority'    => 140,
        )
    );
    
    $wp_customize->add_setting('dignify_portfolio_section_hideshow',
        array(
            'default'           => 'hide',
            'sanitize_callback' => 'dignify_sanitize_select',
        )
    );

    $dignify_portfolio_section_hide_show_option = dignify_section_choice_option();

    $wp_customize->add_control('dignify_portfolio_section_hideshow',
        array(
            'type'        => 'radio',
            'label'       => esc_html__('Portfolio Option', 'dignify'),
            'description' => esc_html__('Show/hide option Section.', 'dignify'),
            'section'     => 'portfolio',
            'choices'     => $dignify_portfolio_section_hide_show_option,
            'priority'    => 1
        )
    );


    // Portfolio title
    $wp_customize->add_setting('dignify_portfolio_title',
        array(
            'default'           => '',
            'type'              => 'theme_mod',
            'sanitize_callback' => 'sanitize_text_field'
        )
     );

    $wp_customize->add_control('dignify_portfolio_title', 
        array(
            'label'    => __('Portfolio Title', 'dignify'),
            'section'  => 'portfolio',
            'priority' => 1
        )
    );
  
    $wp_customize->add_setting('dignify_portfolio_subtitle', 
        array(
            'default'           => '',
            'type'              => 'theme_mod',
            'sanitize_callback' => 'sanitize_text_field'
        )
    );

    $wp_customize->add_control('dignify_portfolio_subtitle',
        array(
            'label'    => __('Portfolio Description', 'dignify'),
            'section'  => 'portfolio', 
            'priority' => 4
        )
     );


    // Portfolio 
   
    $portfolio_no = 6;
        for( $i = 1; $i <= $portfolio_no; $i++ ) {
            $dignify_portfoliopage = 'dignify_portfolio_page_' . $i;
  
    $wp_customize->add_setting( $dignify_portfoliopage,
        array(
            'default'           => 1,
            'sanitize_callback' => 'dignify_sanitize_dropdown_pages',
        )
    );

    $wp_customize->add_control( $dignify_portfoliopage,
        array(
            'label'        => esc_html__( 'Portfolio Page ', 'dignify' ) .$i,
            'section'      => 'portfolio',
            'type'         => 'dropdown-pages',
            'priority'     => 100,
        )
    );
    }
    /** Portfolio Section Settings End **/

    /** Blog Section Settings Start **/

    $wp_customize->add_section('dignify_blog_info', 
        array(
            'title'       => __('Home Blog Section', 'dignify'),
            'description' => '',
            'panel'       => 'frontpage',
            'priority'    => 160
        )
     );
    
    $wp_customize->add_setting('dignify_blog_section_hideshow',
        array(
            'default'           => 'show',
            'sanitize_callback' => 'dignify_sanitize_select',
        )
    );

    $dignify_blog_section_hide_show_option = dignify_section_choice_option();

    $wp_customize->add_control('dignify_blog_section_hideshow',
        array(
            'type'        => 'radio',
            'label'       => esc_html__('Blog Option', 'dignify'),
            'description' => esc_html__('Show/hide option for Blog Section.', 'dignify'),
            'section'     => 'dignify_blog_info',
            'choices'     => $dignify_blog_section_hide_show_option,
            'priority'    => 1
        )
    );
    
    $wp_customize->add_setting('dignify_blog_title', 
         array(
            'default'            => '',
            'type'               => 'theme_mod',
            'sanitize_callback'  => 'sanitize_text_field'
        )
    );

    $wp_customize->add_control('dignify_blog_title', 
        array(
            'label'    => __('Blog Title', 'dignify'),
            'section'  => 'dignify_blog_info',
            'priority' => 1
        )
    );
    
    $wp_customize->add_setting('dignify_blog_subtitle', 
        array(
            'default'             => '',
            'type'                => 'theme_mod',
            'sanitize_callback'   => 'sanitize_text_field'
        )
    );

    $wp_customize->add_control('dignify_blog_subtitle', 
        array(
            'label'    => __('Blog Subheading', 'dignify'),
            'section'  => 'dignify_blog_info', 
            'priority' => 4
        )
    );


     $wp_customize->add_setting( 'dignify_blog_btntxt',
        array(
            'default'           => '',
            'sanitize_callback' => 'sanitize_text_field',
        )
    );

    $wp_customize->add_control( 'dignify_blog_btntxt',
        array(
            'label'        => esc_html__( 'Button-Text','dignify' ),
            'section'      => 'dignify_blog_info',
            'type'         => 'text',
            'priority'     => 100,
        )
    );
        
    $wp_customize->add_setting( 'dignify_blog_btnurl',
        array(
            'default'           => '',
            'sanitize_callback' => 'sanitize_text_field',
        )
    );

    $wp_customize->add_control( 'dignify_blog_btnurl',
        array(
            'label'       => esc_html__( 'Button URL', 'dignify' ),
            'section'     => 'dignify_blog_info',
            'type'        => 'text',
            'priority'    => 100,
        )
    );
    /** Blog Section Settings End **/

}
add_action( 'customize_register', 'dignify_customize_register' );
/**
 * Singleton class for handling the theme's customizer integration.
 *
 * @since  1.0.0
 * @access public
 */
final class dignify_Customize {

	/**
	 * Returns the instance.
	 *
	 * @since  1.0.0
	 * @access public
	 * @return object
	 */
	public static function get_instance() {

		static $instance = null;

		if ( is_null( $instance ) ) {
			$instance = new self;
			$instance->setup_actions();
		}

		return $instance;
	}

	/**
	 * Constructor method.
	 *
	 * @since  1.0.0
	 * @access private
	 * @return void
	 */
	private function __construct() {}

	/**
	 * Sets up initial actions.
	 *
	 * @since  1.0.0
	 * @access private
	 * @return void
	 */
	private function setup_actions() {

		// Register panels, sections, settings, controls, and partials.
		add_action( 'customize_register', array( $this, 'sections' ) );

		// Register scripts and styles for the controls.
		add_action( 'customize_controls_enqueue_scripts', array( $this, 'enqueue_control_scripts' ), 0 );
	}

	/**
	 * Sets up the customizer sections.
	 *
	 * @since  1.0.0
	 * @access public
	 * @param  object  $manager
	 * @return void
	 */
	public function sections( $manager ) {

		// Load custom sections.
		load_template( trailingslashit( get_template_directory() ) . '/include/section-pro.php' );

		// Register custom section types.
		$manager->register_section_type( 'dignify_Customize_Section_Pro' );

		// Register sections.
		$manager->add_section(
			new dignify_Customize_Section_Pro(
				$manager,
				'example_1',
				array(
					'priority'   => 1,
					'title'    => esc_html__( 'Dignify Pro Theme', 'dignify' ),
					'pro_text' => esc_html__( 'Upgrade Pro', 'dignify' ),
					'pro_url'  => esc_url('http://umbrellathemes.com/themes/dignify-pro/'),
				)
			)
		);
		// Register sections.
		$manager->add_section(
			new dignify_Customize_Section_Pro(
				$manager,
				'example_2',
				array(
					'priority'   => 2,
					'title'    => esc_html__( 'Dignify Doc', 'dignify' ),
					'pro_text' => esc_html__( 'Documentation', 'dignify' ),
					'pro_url'  => esc_url('http://umbrellathemes.com/docs/index.html'),
				)
			)
		);
	}

	/**
	 * Loads theme customizer CSS.
	 *
	 * @since  1.0.0
	 * @access public
	 * @return void
	 */
	public function enqueue_control_scripts() {
		wp_enqueue_script( 'fino-customize-controls', trailingslashit( get_template_directory_uri() ) . '/assets/js/customize-controls.js', array( 'customize-controls' ) );
		
		wp_enqueue_style( 'fino-customize-controls', trailingslashit( get_template_directory_uri() ) . '/assets/css/customize-controls.css' );
	}
}

// Doing this customizer thang!
dignify_Customize::get_instance();